===============================
``psyclone.domain.lfric.psyir``
===============================

.. automodule:: psyclone.domain.lfric.psyir

   .. contents::
      :local:

.. currentmodule:: psyclone.domain.lfric.psyir
